store

package
v0.0.0-...-73d7af2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 4, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type IStore

type IStore interface {
	// Initialization
	Init() error

	// User Management
	GetUsers() ([]model.User, error)
	GetUserByName(username string) (model.User, error)
	SaveUser(user model.User) error
	DeleteUser(username string) error

	// Global Settings and Server Configuration
	GetGlobalSettings() (model.GlobalSetting, error)
	GetServer() (model.Server, error)
	SaveServerInterface(serverInterface model.ServerInterface) error
	SaveServerKeyPair(serverKeyPair model.ServerKeypair) error
	SaveGlobalSettings(globalSettings model.GlobalSetting) error

	// Client Management
	GetClients(hasQRCode bool) ([]model.ClientData, error)
	GetClientByID(clientID string, qrCode model.QRCodeSettings) (model.ClientData, error)
	SaveClient(client model.Client) error
	DeleteClient(clientID string) error

	// File Storage Path
	GetPath() string

	// Hash Management for Config Change Detection
	SaveHashes(hashes model.ClientServerHashes) error
	GetHashes() (model.ClientServerHashes, error)
}

IStore defines the interface for data storage used in the application. It abstracts the methods for user management, server configuration, client management, and hash tracking.

Directories

Path Synopsis

Jump to